fix license tag

This commit is contained in:
Tom Callaway 2008-08-07 18:03:24 +00:00
parent 24d7f2192e
commit 50ff60f018
3 changed files with 73 additions and 67 deletions

View File

@ -1,5 +1,57 @@
diff -up lynx2-8-6/userdefs.h.redhat lynx2-8-6/userdefs.h
--- lynx2-8-6/userdefs.h.redhat 2004-12-30 07:11:59.000000000 -0500
+++ lynx2-8-6/userdefs.h 2008-08-07 13:56:42.000000000 -0400
@@ -100,7 +100,7 @@ @@ -100,7 +100,7 @@
* mailcap files (see the examples in the samples directory). * mailcap files (see the examples in the samples directory).
*/ */
@ -83,53 +135,3 @@
#endif #endif
/********************************* /*********************************
--- lynx2-8-6/lynx.cfg.pom 2006-10-24 12:11:37.000000000 +0200
+++ lynx2-8-6/lynx.cfg 2006-10-24 12:39:02.000000000 +0200
@@ -1,7 +1,10 @@
# lynx.cfg file.
-# The default placement for this file is /usr/local/lib/lynx.cfg (Unix)
+# The default placement for this file is /etc/lynx.cfg (Red Hat Linux, Fedora)
# or Lynx_Dir:lynx.cfg (VMS)
#
+# Please don't edit this file directly (it is updated with every Red Hat
+# Linux update, overwriting your changes). Instead, edit /etc/lynx-site.cfg.
+#
# $Format: "#PRCS LYNX_VERSION \"$ProjectVersion$\""$
#PRCS LYNX_VERSION "2.8.6rel.2"
#
@@ -92,7 +95,7 @@
#
# Normally we expect you will connect to a remote site, e.g., the Lynx starting
# site:
-STARTFILE:http://lynx.isc.org/
+STARTFILE:file:/usr/share/doc/HTML/index.html
#
# As an alternative, you may want to use a local URL. A good choice for this is
# the user's home directory:
@@ -396,7 +399,7 @@
# Lynx (case insensitive).
# Find RFC 1345 at http://www.ics.uci.edu/pub/ietf/uri/rfc1345.txt .
#
-#CHARACTER_SET:iso-8859-1
+CHARACTER_SET:utf-8
.h2 LOCALE_CHARSET
# LOCALE_CHARSET overrides CHARACTER_SET if true, using the current locale to
@@ -1776,6 +1779,9 @@
.ex
#DOWNLOADER:Save OS/390 binary file: iconv -f IBM-1047 -t ISO8859-1 %s >%s:FALSE
+# Added by Red Hat:
+DOWNLOADER:View with less:less %s:TRUE
+
.h1 Interaction
@@ -3366,6 +3372,7 @@
#ENABLE_LYNXRC:vi_keys:ON
#ENABLE_LYNXRC:visited_links:ON
.fi
+INCLUDE:/etc/lynx-site.cfg
.h1 External Programs
# Any of the compiled-in pathnames of external programs can be overridden

View File

@ -1,6 +1,7 @@
--- lynx2-8-5/src/HTML.c.crash 2005-01-06 17:03:09.658969996 +0000 diff -up lynx2-8-6/src/HTML.c.crash lynx2-8-6/src/HTML.c
+++ lynx2-8-5/src/HTML.c 2005-01-06 17:07:24.096481825 +0000 --- lynx2-8-6/src/HTML.c.crash 2005-12-18 17:52:30.000000000 -0500
@@ -7001,7 +7001,7 @@ +++ lynx2-8-6/src/HTML.c 2008-08-07 14:00:57.000000000 -0400
@@ -6992,7 +6992,7 @@ static int HTML_end_element(HTStructured
case HTML_SELECT: case HTML_SELECT:
{ {
@ -8,10 +9,10 @@
+ char *ptr = NULL; + char *ptr = NULL;
/* /*
* Make sure we had a select start tag. * Make sure we had a select start tag.
@@ -7041,13 +7041,15 @@ @@ -7032,13 +7032,15 @@ static int HTML_end_element(HTStructured
/* /*
* Finish the previous option. * Finish the previous option.
*/ */
- ptr = HText_setLastOptionValue(me->text, - ptr = HText_setLastOptionValue(me->text,
- me->option.data, - me->option.data,
@ -21,13 +22,13 @@
- me->UCLYhndl, - me->UCLYhndl,
- ATTR_CS_IN); - ATTR_CS_IN);
+ if (!me->first_option) + if (!me->first_option)
+ ptr = HText_setLastOptionValue(me->text, + ptr = HText_setLastOptionValue(me->text,
+ me->option.data, + me->option.data,
+ me->LastOptionValue, + me->LastOptionValue,
+ LAST_ORDER, + LAST_ORDER,
+ me->LastOptionChecked, + me->LastOptionChecked,
+ me->UCLYhndl, + me->UCLYhndl,
+ ATTR_CS_IN); + ATTR_CS_IN);
+ +
FREE(me->LastOptionValue); FREE(me->LastOptionValue);

View File

@ -1,8 +1,8 @@
Summary: A text-based Web browser Summary: A text-based Web browser
Name: lynx Name: lynx
Version: 2.8.6 Version: 2.8.6
Release: 16%{?dist} Release: 17%{?dist}
License: GPL License: GPLv2
Group: Applications/Internet Group: Applications/Internet
Source: http://lynx.isc.org/current/lynx%{version}.tar.bz2 Source: http://lynx.isc.org/current/lynx%{version}.tar.bz2
URL: http://lynx.isc.org/ URL: http://lynx.isc.org/
@ -106,6 +106,9 @@ rm -rf $RPM_BUILD_ROOT
%config(noreplace,missingok) %{_sysconfdir}/lynx-site.cfg %config(noreplace,missingok) %{_sysconfdir}/lynx-site.cfg
%changelog %changelog
* Thu Aug 7 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.8.6-17
- fix license tag
* Thu May 29 2008 Jiri Moskovcak <jmoskovc@redhat.com> - 2.8.6-16 * Thu May 29 2008 Jiri Moskovcak <jmoskovc@redhat.com> - 2.8.6-16
- updated to latest stable version 2.8.6rel5 - updated to latest stable version 2.8.6rel5
- Resolves: #214205 - Resolves: #214205
--- lynx2-8-6/userdefs.h.pom 2004-12-30 13:11:59.000000000 +0100 diff -up lynx2-8-6/lynx.cfg.redhat lynx2-8-6/lynx.cfg
+++ lynx2-8-6/userdefs.h 2006-10-24 12:19:45.000000000 +0200 --- lynx2-8-6/lynx.cfg.redhat 2006-09-18 20:28:28.000000000 -0400
+++ lynx2-8-6/lynx.cfg 2008-08-07 13:58:33.000000000 -0400
@@ -1,7 +1,10 @@
# lynx.cfg file.
# The default placement for this file is /usr/local/lib/lynx.cfg (Unix)
# or Lynx_Dir:lynx.cfg (VMS)
#
+# Please don't edit this file directly (it is updated with every Red Hat
+# Linux update, overwriting your changes). Instead, edit /etc/lynx-site.cfg.
+#
# $Format: "#PRCS LYNX_VERSION \"$ProjectVersion$\""$
#PRCS LYNX_VERSION "2.8.6rel.5"
#
@@ -92,7 +95,7 @@
#
# Normally we expect you will connect to a remote site, e.g., the Lynx starting
# site:
-STARTFILE:http://lynx.isc.org/
+STARTFILE:file:/usr/share/doc/HTML/index.html
#
# As an alternative, you may want to use a local URL. A good choice for this is
# the user's home directory:
@@ -396,7 +399,7 @@ DEFAULT_INDEX_FILE:http://lynx.isc.org/
# Lynx (case insensitive).
# Find RFC 1345 at http://www.ics.uci.edu/pub/ietf/uri/rfc1345.txt .
#
-#CHARACTER_SET:iso-8859-1
+CHARACTER_SET:utf-8
.h2 LOCALE_CHARSET
# LOCALE_CHARSET overrides CHARACTER_SET if true, using the current locale to
@@ -1776,6 +1779,9 @@ DEFAULT_INDEX_FILE:http://lynx.isc.org/
.ex
#DOWNLOADER:Save OS/390 binary file: iconv -f IBM-1047 -t ISO8859-1 %s >%s:FALSE
+# Added by Red Hat:
+DOWNLOADER:View with less:less %s:TRUE
+
.h1 Interaction
@@ -3366,6 +3372,7 @@ COLOR:6:brightred:black
#ENABLE_LYNXRC:vi_keys:ON
#ENABLE_LYNXRC:visited_links:ON
.fi
+INCLUDE:/etc/lynx-site.cfg
.h1 External Programs
# Any of the compiled-in pathnames of external programs can be overridden
@@ -1,7 +1,10 @@
# lynx.cfg file.
-# The default placement for this file is /usr/local/lib/lynx.cfg (Unix)
+# The default placement for this file is /etc/lynx.cfg (Red Hat Linux, Fedora)
# or Lynx_Dir:lynx.cfg (VMS)
#